Summary: LSB Runtime Test Suites
Name: lsb-runtime-test
Version: 3.1.1
# rel is passed in from Makefile so we only have to set the buildno one place
Release: %{rel}
License: Artistic
Group: Development/Tools
Source0: install_scripts-3.1.1.tar.gz
Source1: build_scripts-3.1.1.tar.gz
Source2: lsb-runtime-tests-3.1.1.tar.gz
Source4: wchar.h
Patch0: wchar.h-i18n.patch
Patch1: swscanf.patch
Patch2: getwchar.patch
URL: http://www.linuxbase.org/test
#Prefix: %{_prefix}
BuildRoot: %{_tmppath}/%{name}-root
AutoReqProv: no
Requires: lsb-tet3-lite
BuildRequires: lsb-tet3-lite-devel
%define	tet_root	%{_libdir}/tet
# (sb) - allow us to tune build for debugging issues
%define no_clean	0
%define save_journal	1
# (sb) - defined in Makefile
%define pwd		%{_sourcedir}
# (sb) - set per overrides in rpmbuild command
%{?_with_noclean: %{expand: %%global no_clean 1}}
%{?_without_savejournal: %{expand: %%global save_journal 0}}

%description
This is a binary version of the LSB runtime test suites. This version
is generated from the following source test suites:

lts_vsx-pcts-3.1.1.tgz - POSIX.1 test suite
lts_lsb-os-3.1.1.tgz - LSB-OS test suite
lts_lsb-fhs-3.1.1.tgz - FHS 2.2 test suite
lts_usersgroups-3.1.1.tgz - LSB Users/Groups test suites
lts_li18nux2k.l1-3.1.1.tgz - li18nux2k level 1 test suite
lts_vsthlite-3.1.1.tgz - VSTHlite test suite
lts_lsb-pam-3.1.1.tgz - LSB-PAM test suite

Header file tests from the test suites were removed as
this is an ABI test suite. 

The LSB.os aio tests are not run by default, but are available
separately by running the aio scenario.

*WARNING* This test suite contains a number of setuid and setgid
binaries some of which are owned by root or other users. Other setuid
and setgid binaries may be generated and left behind after execution
of the test suites (especially if certain tests fail). You should not
leave this package installed on production systems or in situations
where local users are not completely trusted.

The test suites use the following tet/vsxgen framework tarball to be 
build and run:

tet_vsxgen_3.7.tgz - tet/vsxgen framework

and install.sh script to be installed and setup.

#==================================================
%prep

LDSO_VERSION=3

%ifarch %{ix86}
LDSO=/lib/ld-lsb.so.$LDSO_VERSION
OLDSO=/lib/ld-linux.so.2
%endif
%ifarch ppc
LDSO=/lib/ld-lsb-ppc32.so.$LDSO_VERSION
OLDSO=/lib/ld.so.1
%endif
%ifarch ppc64
LDSO=/lib64/ld-lsb-ppc64.so.$LDSO_VERSION
OLDSO=/lib64/ld64.so.1
%endif
%ifarch s390
LDSO=/lib/ld-lsb-s390.so.$LDSO_VERSION
OLDSO=/lib/ld.so.1
%endif
%ifarch s390x
LDSO=/lib64/ld-lsb-s390x.so.$LDSO_VERSION
OLDSO=/lib/ld64.so.1
%endif
%ifarch ia64
LDSO=/lib/ld-lsb-ia64.so.$LDSO_VERSION
OLDSO=/lib/ld-linux-ia64.so.2
%endif
%ifarch x86_64
LDSO=/lib64/ld-lsb-x86-64.so.$LDSO_VERSION
OLDSO=/lib64/ld-linux-x86-64.so.2
%endif

cat > LDSOFILE << EOF
LDSO=$LDSO
OLDSO=$OLDSO
EOF

set +x
echo
echo In order to build this RPM you will need to be logged in
echo as root. During the building of the package /home/tet will
echo be removed.
echo
echo Note that if it is necessary the build process will create
echo 'vsx0 accounts and set the password to a default value (lsbtest).'
echo It is highly recommended that you immediately set the password
echo to something else.
echo 

printf "Do you wish to continue (y/n)? [n] "
read cmd
if [ "$cmd" = "y" -o "$cmd" = "Y" ]; then
  echo "Build continuing"
  rm -rf /home/tet
else
  echo Aborting build.
  exit 1
fi
set -x

if [ ! -x /usr/bin/expect ]; then
  echo "Could not find expect, which is required to build the package"
  exit 1
fi

if [ ! -e $LDSO ]
then
  echo "Cannot find $LDSO file on your system"
  echo "Please install the distro lsb support package, create a symbolic"
  echo "link to $OLDSO or install the lsb-dummy package"
  exit 1
fi

%setup -q -c 
%setup -D -b 1 -c
%setup -D -b 2 -c

#==================================================
%build

# read in the saved information from the prep phase
# eventually change this to lsbcc
. ../LDSOFILE
CC="cc -Wall -Wl,--dynamic-linker=${LDSO}"
./auto_install_test_suites

# (sb) use the LSB linker for the early tet compile
sed -i 's|CC = gcc|CC ?= ${CC}|' /home/tet/src/defines.mk

# (sb) this doesn't seem to do anything, get's overwritten
#sed -i 's|CC=\"/usr/bin/cc\"|CC=${CC:-/usr/bin/cc}|' /home/tet/test_sets/SRC/vsxparams

cp auto_configure_test_suites /home/tet/test_sets

# (sb) this one doesn't pick it up from the environment
# seems to be too many chained scripts and it gets dropped
# force the LSB linker for the binaries in TESTROOT/BIN and the tests
cat > /home/tet/test_sets/scripts/common/post-config.sh << EOF
printf 'Changing CC="/usr/bin/cc" to CC="$CC" for common build\n'
sed -i 's|^CC=\"/usr/bin/cc"|CC=\"$CC\"|' SRC/vsxparams
EOF
chmod +x /home/tet/test_sets/scripts/common/post-config.sh

# (sb) setting the environment CC here doesn't seem to matter
#su -c "CC=\"${CC}\" ./auto_configure_test_suites" - vsx0
su -c "./auto_configure_test_suites" - vsx0

# (sb) replace wchar.h with known good one
cp -f %{SOURCE4} /home/tet/test_sets/SRC/SYSINC

#### the next two patches are done here to avoid respinning the tarball
#### for the next release they should be integrated
# (sb) swscanf patch
pushd /home/tet/test_sets
patch -p0 < %{PATCH1}
popd

# patch getwchar testcase
pushd /home/tet/test_sets
patch -p0 < %{PATCH2}
popd

# (sb) we already forced it above because of TESTROOT/BIN
# this vsxparams seems to stick so forget about setting it in the env
# (sb) one more time, should catch the rest of the build
#sed -i 's|CC=\"/usr/bin/cc\"|CC=${CC:-/usr/bin/cc}|' /home/tet/test_sets/SRC/vsxparams
#su -c ". profile;CC=\"${CC}\" tccb -p" - vsx0
su -c ". profile;tccb -p" - vsx0

chown vsx0:vsxg0 *

cp /home/tet/test_sets/DOCS/vsxgde-1.0.pdf .

# Do architecture specific configuration
# (Eg settings in tetexec.cfg file)
./set_config_for_arch

#----------- tet

#==================================================
%install
rm -rf ${RPM_BUILD_ROOT}

mkdir -p ${RPM_BUILD_ROOT}/home/tet/test_sets
mkdir -p ${RPM_BUILD_ROOT}/home/tet/test_sets/results
mkdir -p ${RPM_BUILD_ROOT}/home/tet/LSB.tools
chown -R vsx0:vsxg0 ${RPM_BUILD_ROOT}/home/tet

# (sb) instead of copying the whole mess over and seeing all those 
# unpackaged files, just rsync what we want 
pushd /home/tet/test_sets
for i in BIN TESTROOT scripts profile loopback_disk.ext2 scen.exec tet_code MAN;do
  rsync -a $i ${RPM_BUILD_ROOT}/home/tet/test_sets
done
cd ..
for i in psldefs li18nux_psldefs;do
  rsync -a LSB.tools/$i ${RPM_BUILD_ROOT}/home/tet/LSB.tools
done
popd

# Omit the hdr file tests and utilities which are not part of the LSB spec
egrep -v "ANSI.hdr|POSIX.hdr|PTHR.hdr|LI18NUX2K.L1/(hdr|gui)/|LI18NUX2K.L1/utils/(ed|ex|vi|nm)" ${RPM_BUILD_ROOT}/home/tet/test_sets/scen.exec > /tmp/scen.exec.$$

# move the aio tests into a new section
grep -v /aio/ /tmp/scen.exec.$$ | sed -e 's/LSB.os 908/LSB.os 785/' > /tmp/scen.exec.new.$$
cat >> /tmp/scen.exec.new.$$ <<EOF
aio
        "total tests in LSB.os 123"
EOF
grep /aio/ /tmp/scen.exec.$$ >> /tmp/scen.exec.new.$$
cp /tmp/scen.exec.new.$$ ${RPM_BUILD_ROOT}/home/tet/test_sets/scen.exec
rm -f /tmp/scen.exec.$$ /tmp/scen.exec.new.$$

# move the syslog tests into a new section
cp ${RPM_BUILD_ROOT}/home/tet/test_sets/scen.exec /tmp/scen.exec.$$
egrep -v "syslog|openlog|closelog" /tmp/scen.exec.$$ | sed -e 's/LSB.os 785/LSB.os 661/' > /tmp/scen.exec.new.$$
cat >> /tmp/scen.exec.new.$$ <<EOF
syslog
        "total tests in LSB.os 248"
EOF
egrep "syslog|openlog|closelog" /tmp/scen.exec.$$ >> /tmp/scen.exec.new.$$
cp /tmp/scen.exec.new.$$ ${RPM_BUILD_ROOT}/home/tet/test_sets/scen.exec
rm -f /tmp/scen.exec.$$ /tmp/scen.exec.new.$$

# Omit the gets file interface tests which are not part of the LSB spec
egrep -v "ANSI.os/streamio/(Mgets|gets)/T.gets" ${RPM_BUILD_ROOT}/home/tet/test_sets/scen.exec > /tmp/scen.exec.$$

# adjust the test counts
cat /tmp/scen.exec.$$ | sed -e 's/ANSI.os 1536/ANSI.os 1522/' > /tmp/scen.exec.new.$$

cp /tmp/scen.exec.new.$$ ${RPM_BUILD_ROOT}/home/tet/test_sets/scen.exec
rm -f /tmp/scen.exec.$$ /tmp/scen.exec.new.$$

# Delete the ANSI.hdr and POSIX.hdr tests
rm -rf ${RPM_BUILD_ROOT}/home/tet/test_sets/TESTROOT/tset/ANSI.hdr
rm -rf ${RPM_BUILD_ROOT}/home/tet/test_sets/TESTROOT/tset/POSIX.hdr

# Delete the VSTHlite PTHR.hdr tests
rm -rf ${RPM_BUILD_ROOT}/home/tet/test_sets/TESTROOT/tset/PTHR.hdr

# Delete the li8nux2k.l1 hdr and gui tests
rm -rf ${RPM_BUILD_ROOT}/home/tet/test_sets/TESTROOT/tset/LI18NUX2k.L1/hdr
rm -rf ${RPM_BUILD_ROOT}/home/tet/test_sets/TESTROOT/tset/LI18NUX2k.L1/gui

cp post_install.sh ${RPM_BUILD_ROOT}/home/tet/test_sets/BIN/
chmod a+x ${RPM_BUILD_ROOT}/home/tet/test_sets/BIN/post_install.sh
cp /home/tet/test_sets/SRC/install/scripts/editcfg.sh ${RPM_BUILD_ROOT}/home/tet/test_sets/BIN/
# Tailor run_tests script for architecture
cp .profile ${RPM_BUILD_ROOT}/home/tet/test_sets
. ../LDSOFILE
cat > change_ldso.sh << EOF
sed -e "s@BUILD_VERSION=@BUILD_VERSION=\"${RPM_PACKAGE_VERSION}-${RPM_PACKAGE_RELEASE} ($RPM_ARCH)\"@" -e "s@^LDSO=@LDSO=\"$LDSO\"@" -e "s@^OLDSO=@OLDSO=\"$OLDSO\"@"  run_tests > ${RPM_BUILD_ROOT}/home/tet/test_sets/run_tests
EOF
chmod a+x change_ldso.sh && ./change_ldso.sh && rm -f change_ldso.sh
rm -f ../LDSOFILE
chmod a+x ${RPM_BUILD_ROOT}/home/tet/test_sets/run_tests

# (sb) docs
%define docdir /opt/lsb/doc/runtime-test
mkdir -p $RPM_BUILD_ROOT/%{docdir}
cp Artistic README vsxgde-1.0.pdf runtime-files.txt $RPM_BUILD_ROOT/%{docdir}

# (sb) file verification/fix script
mkdir -p $RPM_BUILD_ROOT/opt/lsb/bin
cp verify-runtime.sh $RPM_BUILD_ROOT/opt/lsb/bin

# Copy the li18nux pseudo languages that we need
cp /home/tet/test_sets/tset/LI18NUX2K.L1/base/nl_langinfo/LTP_IL* ${RPM_BUILD_ROOT}/home/tet/LSB.tools/li18nux_psldefs/

%if %{save_journal}
  cp -f /home/tet/test_sets/results/0001b/journal %{pwd}/tetbuild.journal
%endif

#==================================================
%clean
# uncomment later. leave in now for speed
if [ -e "${RPM_BUILD_ROOT}"  -a "${RPM_BUILD_ROOT}" != "/" ]; then 
    rm -rf ${RPM_BUILD_ROOT}
fi
%if !%{no_clean}
  rm -rf /home/tet
%endif

#======================================================================
%pre

# Need to create some groups and users beforehand because
# when the files are unpacked they need to be owned by the correct user
mkdir -p /home/tet/test_sets
groupadd vsxg0 > /dev/null 2>&1 || true
groupadd vsxg1 > /dev/null 2>&1 || true
groupadd vsxg2 > /dev/null 2>&1 || true
useradd -g vsxg0 -d /home/tet/test_sets -s /bin/sh -c "VSX0 test login" vsx0 > /dev/null 2>&1 || true
useradd -g vsxg1 -d /home/tet -s /bin/sh -c "VSX1 test login" vsx1 > /dev/null 2>&1 || true
useradd -g vsxg2 -d /home/tet -s /bin/sh -c "VSX2 test login" vsx2 > /dev/null 2>&1 || true
passwd -n 0 vsx0 > /dev/null 2>&1 || true
passwd -n 0 vsx1 > /dev/null 2>&1 || true
passwd -n 0 vsx2 > /dev/null 2>&1 || true

#======================================================================
%post

# Do post install setup
/home/tet/test_sets/BIN/post_install.sh

echo
echo You have added 3 user accounts into your system: vsx0, vsx1 and vsx2,
echo which are needed during the tests. But no password has been set for them.
echo 
echo Before run the tests, please choose a robust password for these users.
echo For example a combination of digits and upper and lower case letters.
echo 
echo To run the tests, please log in as vsx0 and follow the displayed instructions,
echo or su to vsx0 from root.
echo

# After new installation the test suites are no longer configured, so
# we remove this file
rm -f /home/tet/test_sets/.configured

#==================================================
%files
%defattr(-,vsx0,vsxg0)
/home/tet/test_sets/BIN
/home/tet/test_sets/TESTROOT
/home/tet/test_sets/scripts
/home/tet/test_sets/profile
/home/tet/test_sets/loopback_disk.ext2
/home/tet/test_sets/scen.exec
/home/tet/test_sets/tet_code
/home/tet/test_sets/.profile
/home/tet/test_sets/MAN

# (sb) files with special ownership
%defattr(-,root,vsxg0)
/home/tet/test_sets/TESTROOT/tset/ANSI.os/genuts/system_X/sys_t56
/home/tet/test_sets/TESTROOT/tset/ANSI.os/genuts/system_X/sys_t57
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/Mgetc/getc_su
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/Mputc/putc_t11
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fclose/fclose_t18
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fflush/fflush_t13
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fgets/fgets_su
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fopen/fopen_t23
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fopen/fopen_t30
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fputs/fputs_t11
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fread/fread_su
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/freopen/freop_t25
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/freopen/freop_t30
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fseek/fseek_t15
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fwrite/fwrite_t17
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/getc/getc_su
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/gets/gets_su
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/printf/printf_t68
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/putc/putc_t11
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/puts/puts_t11
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/remove/remove_su
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/scanf/scanf_su
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/vprintf/vprintf_t68
/home/tet/test_sets/TESTROOT/tset/LI18NUX2K.L1/utils/localedef/localedef_priv
/home/tet/test_sets/TESTROOT/tset/LSB.os/genuts/closelog_L/setupsyslog
/home/tet/test_sets/TESTROOT/tset/LSB.os/genuts/nftw/T.nftw
/home/tet/test_sets/TESTROOT/tset/LSB.os/genuts/openlog_L/setupsyslog
/home/tet/test_sets/TESTROOT/tset/LSB.os/genuts/pclose/pclose_t6
/home/tet/test_sets/TESTROOT/tset/LSB.os/genuts/syslog_L/setupsyslog
/home/tet/test_sets/TESTROOT/tset/LSB.os/ioprim/readv_L/readv_L_su
/home/tet/test_sets/TESTROOT/tset/LSB.os/ioprim/writev_L/writev_L_su
/home/tet/test_sets/TESTROOT/tset/LSB.os/ipc/msgctl/T.msgctl
/home/tet/test_sets/TESTROOT/tset/LSB.os/ipc/msgsnd/T.msgsnd
/home/tet/test_sets/TESTROOT/tset/LSB.os/ipc/semctl/T.semctl
/home/tet/test_sets/TESTROOT/tset/LSB.os/ipc/shmctl/T.shmctl
/home/tet/test_sets/TESTROOT/tset/LSB.os/mfiles/msync/T.msync
/home/tet/test_sets/TESTROOT/tset/LSB.os/mfiles/munmap/T.munmap
/home/tet/test_sets/TESTROOT/tset/LSB.os/procenv/chroot/T.chroot
/home/tet/test_sets/TESTROOT/tset/LSB.os/procenv/cuserid/cuserid_su
/home/tet/test_sets/TESTROOT/tset/LSB.os/procenv/nice/T.nice
/home/tet/test_sets/TESTROOT/tset/LSB.os/procenv/nice_X/nice_X1
/home/tet/test_sets/TESTROOT/tset/LSB.os/procenv/ulimit/ulimit_t4
/home/tet/test_sets/TESTROOT/tset/LSB.os/procprim/execl/execl3
/home/tet/test_sets/TESTROOT/tset/LSB.os/procprim/execle/execle3
/home/tet/test_sets/TESTROOT/tset/LSB.os/procprim/execlp/execlp3
/home/tet/test_sets/TESTROOT/tset/LSB.os/procprim/execv/execv3
/home/tet/test_sets/TESTROOT/tset/LSB.os/procprim/execve/execve3
/home/tet/test_sets/TESTROOT/tset/LSB.os/procprim/execvp/execvp3
/home/tet/test_sets/TESTROOT/tset/LSB.os/procprim/fork/fork2
/home/tet/test_sets/TESTROOT/tset/LSB.os/procprim/fork/fork8
/home/tet/test_sets/TESTROOT/tset/LSB.pam/testcases/pam_acct_mgmt/pam_acct_mgmt
/home/tet/test_sets/TESTROOT/tset/LSB.pam/testcases/pam_authenticate/pam_authenticate
/home/tet/test_sets/TESTROOT/tset/LSB.pam/testcases/pam_chauthtok/pam_chauthtok
/home/tet/test_sets/TESTROOT/tset/LSB.pam/testcases/pam_close_session/pam_close_session
/home/tet/test_sets/TESTROOT/tset/LSB.pam/testcases/pam_fail_delay/pam_fail_delay
/home/tet/test_sets/TESTROOT/tset/LSB.pam/testcases/pam_open_session/pam_open_session
/home/tet/test_sets/TESTROOT/tset/LSB.pam/testcases/pam_setcred/pam_setcred
/home/tet/test_sets/TESTROOT/tset/LSB.usersgroups/cinterface/initgroups/T.initgroups
/home/tet/test_sets/TESTROOT/tset/LSB.usersgroups/commands/passwd/root_helper
/home/tet/test_sets/TESTROOT/tset/LSB.usersgroups/commands/passwd/uberpass
/home/tet/test_sets/TESTROOT/tset/POSIX.os/dataform/cpio/cpio_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/dataform/tar/tar_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/devclass/tcgetpgrp/tcgetpg_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/chdir/chdir_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/chmod/T.chmod
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/chown/T.chown
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/creat/creat_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/creat/creat_t30
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/link/T.link
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/mkdir/mkdir_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/mkdir/mkdir_t19
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/mkfifo/mkfifo_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/mkfifo/mkfifo_t17
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t20_3
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t44
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t46
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/opendir/opendir_t5
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/pathconf/pathcf_t19
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/rename/rename_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/rename/rename_t17
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/rmdir/rmdir_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/rmdir/rmdir_t9
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/unlink/T.unlink
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/unlink/unlink_t9
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/utime/T.utime
/home/tet/test_sets/TESTROOT/tset/POSIX.os/ioprim/read/read_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/ioprim/write/write_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/getgid/T.getgid
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/getgroups/T.getgroups
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/getlogin/T.getlogin
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/getuid/T.getuid
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/setgid/setgid_t01
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/setgid/setgid_t03
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/setuid/setuid_t01
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/setuid/setuid_t03
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/exec/exec_setid
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/exec/exec_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/exec/exec_tstop
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/fork/fork_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/fork/fork_t18
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/fork/fork_t21
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/kill/kill_su
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/kill/kill_t12
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/kill_X/kill_su_X
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/asctime_r/T.asctime_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/ctime_r/T.ctime_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/getc_unlocked/T.getc_unlocked
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/getchar_unlocked/T.getchar_unlocked
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/getchar_unlocked/getchar_unlocked_exectests
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/gmtime_r/T.gmtime_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/localtime_r/T.localtime_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/localtime_r/localtime_r_exectests
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/rand_r/T.rand_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/cfuncs/strtok_r/T.strtok_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/files/readdir_r/T.readdir_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/procenv/getlogin_r/T.getlogin_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/procenv/ttyname_r/T.ttyname_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/sysdb/getgrgid_r/T.getgrgid_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/sysdb/getgrnam_r/T.getgrnam_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/sysdb/getpwnam_r/T.getpwnam_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/sysdb/getpwuid_r/T.getpwuid_r
/home/tet/test_sets/TESTROOT/tset/PTHR.os/thread/pthread_create/T.pthread_create
/home/tet/test_sets/TESTROOT/tset/PTHR.os/thread/pthread_create/pthread_create_exectests

# (sb) more files with special ownership
%defattr(-,vsx0,vsxg1)
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/mkdir/mkdir_t5
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/mkfifo/mkfifo_t5
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/getegid/getegid_t1
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/setgid/setgid_sg1

# (sb) more files with special ownership
%defattr(-,vsx0,vsxg2)
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/getgid/getgid_t01

# (sb) more files with special ownership
%defattr(-,root,vsxg2)
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/access/T.access

# (sb) more files with special ownership
%defattr(-,vsx1,vsxg0)
/home/tet/test_sets/TESTROOT/tset/LSB.os/procenv/cuserid/T.cuserid
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/mkdir/mkdir_t4
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/mkfifo/mkfifo_t4
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/geteuid/geteuid_t1
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/setuid/setuid_su1

# (sb) more files with special ownership
%defattr(-,vsx2,vsxg0)
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procenv/getuid/getuid_t01

# (sb) more files with special ownership
%defattr(-,vsx1,vsxg1)
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fopen/fopen_t2
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fopen/fopen_t29
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/fopen/fopen_t33
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/freopen/freop_t2
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/freopen/freop_t29
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/freopen/freop_t37
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/tmpfile/tmpfile_t2
/home/tet/test_sets/TESTROOT/tset/ANSI.os/streamio/tmpfile/tmpfile_t8
/home/tet/test_sets/TESTROOT/tset/LSB.os/ipc/semget/T.semget
/home/tet/test_sets/TESTROOT/tset/LSB.os/ipc/semop/T.semop
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/creat/creat_t10
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/creat/creat_t11
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/creat/creat_t29
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/creat/creat_t7
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/creat/creat_t8
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/fstat/fstat_t1
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t10
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t14
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t15
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t16
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t45
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/open/open_t9
/home/tet/test_sets/TESTROOT/tset/POSIX.os/files/opendir/opendir_t14
/home/tet/test_sets/TESTROOT/tset/POSIX.os/ioprim/pipe/pipe_t10
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/exec/exec_tfail
/home/tet/test_sets/TESTROOT/tset/POSIX.os/procprim/exec/exec_tok

# (sb) more files with special ownership
%defattr(-,root,root)
%dir /home/tet/LSB.tools
/home/tet/test_sets/run_tests
/home/tet/test_sets/BIN/editcfg.sh
/home/tet/test_sets/BIN/post_install.sh
/home/tet/test_sets/TESTROOT/.keepme
/home/tet/test_sets/TESTROOT/tset/LSB.usersgroups/cinterface/setegid/T.setegid
/home/tet/test_sets/TESTROOT/tset/LSB.usersgroups/cinterface/seteuid/T.seteuid
/home/tet/test_sets/TESTROOT/tset/LSB.usersgroups/commands/misc/T.misc

%defattr(-,vsx0,vsxg0)
%dir /home/tet
%dir /home/tet/test_sets
%dir /home/tet/test_sets/results

# Need pseudo language stuff
/home/tet/LSB.tools/psldefs
/home/tet/LSB.tools/li18nux_psldefs

%defattr(-,root,root)
%{docdir}/Artistic 
%{docdir}/README 
%{docdir}/vsxgde-1.0.pdf
%{docdir}/runtime-files.txt
/opt/lsb/bin/verify-runtime.sh

#==================================================
%changelog
* Mon Jan 22 2007 Stew Benedict <stewb@aysenterprises.com> 3.1.1-2
- add options to capture the build journal, not clean /home/tet
- add -Wall to cc options to help in debugging issues
- P0: patch wchar.h in SRC/SYSINC (copied from build host) for i18n issues
- P1: move test 19 in swscanf to before tests 12 and 14

* Wed Jan 10 2007 Stew Benedict <stewb@aysenterprises.com>
- 3.1.1 update build
- drop the SPECFILE detection - doesn't work with newer gcc 
- encourage the use of the LSB linker in the build
- only rsync what we need in %%install
- explicitly list the files with special ownership
- place docs in /opt/lsb/doc
- #1417 - deal with PASS_MIN_DAYS on test system
- #1427 - permission checker/restorer (feature request)
- #1482 - try to detect csh before asking about it
- #1543 - fix common.c for gcc41 build

* Wed May 5 2004 Chris Yeoh <cyeoh@samba.org>
- Second beta of 2.0 test suites

* Wed Mar 17 2004 Chris Yeoh <cyeoh@samba.org>
- First beta of 2.0 test suites

* Mon Jul 17 2003 Chris Yeoh <cyeoh@samba.org
- Updated test suites for 1.3.6 release

* Mon Apr 14 2003 Chris Yeoh <cyeoh@samba.org
- Updated test suites for 1.3.5 release

* Mon Mar 3 2003 Chris Yeoh <cyeoh@samba.org>
- Updated test suites for 1.3.4 release

* Wed Jan 15 2003 Chris Yeoh <cyeoh@samba.org>
- Updated test suites

* Wed Dec 4 2002 Chris Yeoh <cyeoh@samba.org>
- Update for new lsb-os, vsx-pcts, li8nux2k and lsb-fhs test suites
- Now installs required li8nux2k locales before tests executed.

* Thu Nov 21 2002 Chris Yeoh <cyeoh@samba.org>
- Adds vsthlite test suite
- Adds li8nux2k.l1 test suite
- LSB 1.3 Beta program

* Wed Oct 23 2002 Chris Yeoh <cyeoh@samba.org>
- Update for new lsb-os, vsx-pcts test suites
- Updated TET/VSXgen tarball to support testing on implementations that
  use function descriptors

* Fri Sep 20 2002 Chris Yeoh <cyeoh@samba.org>
- Update for new lsb-os, vsx-pcts, usersgroups and fhs test suites
- Adds MAN pages back into binary package as these are used
  by vrpt test tool.

* Thu Jun 27 2002 Chris Yeoh <cyeoh@samba.org>
- Incorporates fix from lsb-fhs-1.2.2.1 so that
  optional c shell support can be disabled correctly

* Mon Jun 17 2002 Chris Yeoh <cyeoh@samba.org
- Incorporates tet_vsxgen 2.3 (PPC32 stdarg fix)
- Incorporates fix for run_tests IA64 fix

* Wed May 29 2002 Chris Yeoh <cyeoh@samba.org>
- Update for new lsb-os, usersgroups and lsb-fhs test suites

* Wed May 1 2002 Chris Yeoh <cyeoh@samba.org>
- Update for new lsb-os, vsx-pcts and lsb-fhs test suites

* Tue Apr 23 2002 Chris Yeoh <cyeoh@samba.org>
- Update for new lsb-os, vsx-pcts and usersgroups test suites

* Sun Apr 7 2002 Chris Yeoh <cyeoh@samba.org>
- Update for new lsb-os, vsx-pcts and tet_vsxgen
- Adds better error reporting/checking to running of test 
  suites

* Wed Mar 13 2002 Chris Yeoh <cyeoh@samba.org>
- Rebuild for updated lsb-os and vsx-pcts test suites
- Removal of automatic running of aio tests
- Renaming of package to lsb-runtime-test to be more consistent
  with wider LSB naming scheme

* Tue Mar 12 2002 Chris Yeoh <cyeoh@samba.org>
- Adds automatic marking of package version into journal

* Tue Feb 12 2002 Chris Yeoh <cyeoh@samba.org>
- Fix creation of home directories fro vsx1, vsx2 in preinstall script
- Invalidate configuration on installation/upgrade
- Add tjreport
- Rebuild with updated lsb-os test suite

* Thu Jan 24 2002 Chris Yeoh <cyeoh@samba.org>
- Update for updated lsb-os test suite (minor change)
- Recompile with fixed stub libraries

* Fri Jan 18 2002 Chris Yeoh <cyeoh@samba.org>
- Update for updated usersgroups and fhs test suites
- Recompile with dynamically linked getspnam
- Update documentation

* Mon Dec 17 2001 Chris Yeoh <cyeoh@samba.org>
- Adds /sbin and /usr/sbin to path for vsx0 user
- Compiled with PATH_MAX set to 4096

* Thu Dec 13 2001 Chris Yeoh <cyeoh@samba.org>
- Update for new lsb-os release
- Add vsxgde-1.0.pdf in rpm
- Add lsb-fhs questions on first run of tests
- No longer include header file tests

* Mon Dec 3 2001 Chris Yeoh <cyeoh@samba.org>
- Fixes source build problem where vsx users do not already exist
- Checks for expect before building
- Clarifies post installation message to make it clearer as to what to do
  next

* Tue Nov 27 2001 Chris Yeoh <cyeoh@samba.org>
- Updates RPM to build test suites totally from source

* Wed Oct 10 2001 Chris Yeoh <cyeoh@samba.org>
- Adds lsb-fhs and lsb-usersgroups test suites
- Updates other test suites and tet/vsxgen harness

* Wed Jun 6 2001 Chris Yeoh <cyeoh@samba.org>
- Update for new source test suites. Now includes
  lsb-os test suite
- Various bug fixes of installation/setup scripts

* Wed May 9 2001 Chris Yeoh <cyeoh@samba.org>
- Create.

